@@ -225,7 +225,7 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
         p._new_edge = (u0, v1)
         self._proposal_edges.append(p)
 
-    #@MarkovChainMonteCarlo.proposal_efficiency
+    @MarkovChainMonteCarlo.proposal_efficiency
     def swap_condition(
         self, G: nx.Graph, e0s: list, e1s: list, u0: int, v0: int
     ) -> bool:
@@ -362,12 +362,9 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
         convergence_count: int = 0
         while convergence_count <= self._convergence_limit:
 
-            self._proposal_count += 1
             if convergence_count % 50 == 0 and self._proposal_count != 0:
                 self._acceptance_ratio.append(
-                    (
-                        self._proposal_count, float(convergence_count) / float(self._proposal_count)
-                    )
+                    float(self._proposals_accepted) / float(self._proposal_count)
                 )
 
             # pick an edge at random.
@@ -409,9 +406,6 @@ class MarkovChainMonteCarloRewiring(MarkovChainMonteCarlo):
 
                 convergence_count += 1
 
-                if convergence_count % 1000 == 0:
-                    print(convergence_count)
-
                 # add the new proposal edges for both sides
                 for pe in self._proposal_edges:
                     e: tuple = pe._new_edge
